@@ -6,17 +6,17 @@ c
       use amr_module
       implicit double precision (a-h,o-z)
       integer newnumgrids(maxlv)
-      integer clock_start2, clock_finish, clock_rate
+      integer(kind=8) :: clock_start2, clock_finish, clock_rate
 c
 c :::::::::::::::::::::::::::: REGRID :::::::::::::::::::::::::::::::
 
-c  regrid = flag points on each grid with a level > = lbase.
-c  cluster them, and fit new subgrids around the clusters.
-c  the lbase grids stay fixed during regridding operation.
-c  when a parent grid has its error estimated, add its kid grid
-c  information to the error grid before clustering. (project)
-c  order of grid examination - all grids at the same level, then
-c  do the next coarser level.
+!> Flag points on each grid with a level > = lbase.
+!! cluster them, and fit new subgrids around the clusters.
+!! the lbase grids stay fixed during regridding operation.
+!! when a parent grid has its error estimated, add its kid grid
+!! information to the error grid before clustering. (project)
+!! order of grid examination - all grids at the same level, then
+!! do the next coarser level.
 c
 c input parameters:
 c     lbase  = highest level that stays fixed during regridding
@@ -107,16 +107,28 @@ c        balancing, but doesn't help locality
          if (verbosity_regrid .ge. levnew) then
            write(*,100) ngridcount,ncells,levnew
            write(outunit,100) ngridcount,ncells,levnew
- 100       format("there are ",i4," grids with ",i8,
+ 100       format("there are ",i6," grids with ",i10,
      &            " cells at level ", i3)
          endif
 72     continue
+c
+c      set up array of grids instead of recomputing at each step
+       call makeGridList(lbase)
+       do levnew = lbase+1, lfine
+          call makeBndryList(levnew)   ! does one level at a time
+       end do
 
       return
       end
 c
 c -------------------------------------------------------------------
 c
+!> Sort all grids at level **level**. 
+!! Put the most expensive grid in **lstart(level)** 
+!! Cost is measured by number of cells.
+!! The linked list was also sorted such that the cost of grids
+!! decreases from list head to list tail
+
       subroutine arrangeGrids(level, numg)
 c
       use amr_module
@@ -129,8 +141,8 @@ c
        mptr = lstart(level)
        do i = 1, numg
          listgrids(i) = mptr
-         cost(i) =  (node(ndihi,mptr)-node(ndilo,mptr)+1) *
-     1              (node(ndjhi,mptr)-node(ndjlo,mptr)+1)
+         cost(i) =  (node(ndihi,mptr)-node(ndilo,mptr)+3) *
+     1              (node(ndjhi,mptr)-node(ndjlo,mptr)+2)
          index(i) = i
          mptr = node(levelptr, mptr)
        end do
