@@ -56,7 +56,7 @@ module gauges_module
         real(kind=8) :: last_time
 
         ! Output settings
-        integer :: file_format
+        integer :: file_format, gtype
         real(kind=8) :: min_time_increment
         character(len=10) :: display_format
         logical, allocatable :: q_out_vars(:)
@@ -135,11 +135,20 @@ contains
             read(UNIT, *)
             read(UNIT, *)
             read(UNIT, *) (gauges(i)%min_time_increment, i=1, num_gauges)
+            read(UNIT, *)
+            read(UNIT, *)
+            read(UNIT, *) (gauges(i)%gtype, i=1, num_gauges)
 
             ! Read in q fields
             read(UNIT, *)
             read(UNIT, *)
             do i = 1, num_gauges
+                if (gauges(i)%gtype .ne. 1) then
+                    write(6,*) '*** Lagrangian gauges not yet supported'
+                    write(6,*) '*** All gauges must have gtype==1'
+                    stop
+                endif
+
                 allocate(gauges(i)%q_out_vars(num_eqn))
                 read(UNIT, *) gauges(i)%q_out_vars
 
