@@ -13,10 +13,12 @@
       use amr_module
       implicit none
 
-       if (.not.allocated(storage)) then
-          memsize = 2000000
-          allocate(storage(memsize))
-          alloc => storage
+!      if (.not.allocated(storage)) then   ! old way, changed mjb jan. 2015
+       if (.not.allocated(alloc)) then     ! new way, use allocatable arrays, not pointers
+          memsize = 4000000
+!         allocate(storage(memsize))
+          allocate(alloc(memsize))
+!          alloc => storage
           print *, "Storage allocated..."
       else
           print *, "Storage already allocated!"
