@@ -23,6 +23,7 @@ make_files = glob.glob("Makefile")
 f_files = glob.glob("*.f") + glob.glob("*.f90")
 py_files = glob.glob("*.py")
 m_files = glob.glob("*.m")
+ipynb_files = glob.glob("*.ipynb")
 out_dirs = glob.glob("_out*")   # not currently listed on html page
 plot_dirs = glob.glob("_plots") # for gallery -- want only main _plots
 #plot_dirs = glob.glob("_plot*")   # might want to list other plot directories
@@ -46,6 +47,14 @@ for f in py_files:
     if not os.path.isfile(flink): flink = f
     py_text = py_text + '<li><a href="%s">%s</a>\n' % (flink,f)
 
+ipynb_text = "\n"
+for f in ipynb_files:
+    flink = f.replace('.ipynb', '.html')
+    if os.path.isfile(flink): 
+        ipynb_text = ipynb_text + '<li><a href="%s">%s</a>\n' % (flink,f)
+    else:
+        print('*** Found %s but missing %s' % (f,flink))
+
 m_text = "\n"
 for f in m_files:
     flink = f + '.html'
@@ -65,7 +74,7 @@ for f in plot_dirs:
 
 
 new_text = """
-<h2>Files</h2>
+<h2>Files (html versions)</h2>
 <ul>
 %s
 <p>
@@ -76,9 +85,11 @@ new_text = """
 %s
 <p>
 %s
+<p>
+%s
 </ul>
 <p>
-""" % (make_text,f_text,py_text,m_text,plot_text)
+""" % (make_text,f_text,ipynb_text,py_text,m_text,plot_text)
 
 # If README.rst contains a section labelled "Version", insert the list of
 # files before this section.  Otherwise put list of files at end...
@@ -96,12 +107,12 @@ html_string = html_string.replace(r'<h1>Version</h1>','<h2>Version</h2>')
 
 # Fix head for Clawpack style:
 head_text = """
-<link rel="icon" href="http://www.clawpack.org/clawicon.ico" />
+<link rel="icon" href="http://www.clawpack.org/_static/clawicon_new.ico" />
 </head>
 <body BGCOLOR="#FFFFE8" LINK="#7F0000" VLINK="#7F0000">
 <font FACE="TREBUCHET MS,HELVETICA,ARIAL">
 <a href="http://www.clawpack.org">
-<IMG SRC="http://www.clawpack.org/clawlogo.jpg" WIDTH="200" HEIGHT="70" 
+<IMG SRC="http://www.clawpack.org/_static/clawlogo_border.jpg" WIDTH="250" HEIGHT="70" 
 VSPACE="0" HSPACE="0" ALT="CLAWPACK" BORDER="0" LOOP="0"> </a>
 """
 
