@@ -3,7 +3,8 @@
 Module to create topo and qinit data files for this example.
 """
 
-from clawpack.geoclaw.topotools import topo1writer, topo2writer
+from __future__ import absolute_import
+from clawpack.geoclaw.topotools import Topography
 from numpy import *
 
 #from pyclaw.data import Data
@@ -26,7 +27,12 @@ def maketopo():
     xlower = -2.e0
     ylower = -2.e0
     outfile= "bowl.topotype2"
-    topo2writer(outfile,topo,xlower,xupper,ylower,yupper,nxpoints,nypoints)
+
+    topography = Topography(topo_func=topo)
+    topography.x = linspace(xlower,xupper,nxpoints)
+    topography.y = linspace(ylower,yupper,nypoints)
+    topography.write(outfile, topo_type=2, Z_format="%22.15e")
+
 
 def topo(x,y):
     """
