@@ -1,20 +1,24 @@
 subroutine src2(meqn,mbc,mx,my,xlower,ylower,dx,dy,q,maux,aux,t,dt)
       
     use storm_module, only: wind_forcing, pressure_forcing
-    use storm_module, only: rho_air, wind_drag, ambient_pressure
+    use storm_module, only: wind_drag
     use storm_module, only: wind_index, pressure_index
     use storm_module, only: storm_direction, storm_location
 
     use friction_module, only: friction_index
 
-    use geoclaw_module, only: g => grav, RAD2DEG, pi
-    use geoclaw_module, only: coriolis_forcing, coriolis
+    use geoclaw_module, only: g => grav, RAD2DEG, pi, rho_air, ambient_pressure
+    use geoclaw_module, only: coriolis_forcing, coriolis, rho
     use geoclaw_module, only: friction_forcing, friction_depth
+    use geoclaw_module, only: manning_coefficient
+    use geoclaw_module, only: manning_break, num_manning
     use geoclaw_module, only: spherical_distance, coordinate_system
 
     use amr_module, only: mcapa, cflv1
       
-    use multilayer_module, only: num_layers, rho, dry_tolerance
+    use multilayer_module, only: num_layers, dry_tolerance
+    
+    use friction_module, only: variable_friction, friction_index
 
     implicit none
     
@@ -27,99 +31,28 @@ subroutine src2(meqn,mbc,mx,my,xlower,ylower,dx,dy,q,maux,aux,t,dt)
     real(kind=8), intent(inout) :: aux(maux,1-mbc:mx+mbc,1-mbc:my+mbc)
 
     ! Locals
-    integer :: i, j, m, k, bottom_index, bottom_layer, layer_index
+    integer :: i, j, m, k, bottom_index, bottom_layer, layer, nman
     logical :: found
     real(kind=8) :: xm, xc, xp, ym, yc, yp, dx_meters, dy_meters
-    real(kind=8) :: h(num_layers), hu, hv, u, v, hu0, hv0
+    real(kind=8) :: h(num_layers), hu, hv, u, v, hu0, hv0, coeff
     real(kind=8) :: tau, wind_speed, theta, phi, psi, P_gradient(2), S(2), sloc(2)
     real(kind=8) :: fdt, Ddt, a(2,2)
 
     ! Physics parameters
-    real(kind=8), parameter :: fric_coefficient = 7.d0 / 3.d0
+    real(kind=8), parameter :: manning_power = 7.d0 / 3.d0
     real(kind=8), parameter :: H_break = 2.d0
     real(kind=8), parameter :: theta_f = 10.d0
     real(kind=8), parameter :: gamma_f = 4.d0 / 3.d0
 
-    ! Algorithm parameters
-    ! Here to prevent a divide by zero in friction term
-    real(kind=8), parameter :: friction_tolerance = 1.0d-30
-
-    character(len=*), parameter :: CFL_FORMAT =   &
-                        "('*** WARNING *** Courant number  =', d12.4," // &
-                         "'  is larger than input cfl_max = ', d12.4," // &
-                         "' in src2.')"
-
     ! Algorithm parameters
     ! Parameter controls when to zero out the momentum at a depth in the
     ! friction source term
     real(kind=8), parameter :: depth_tolerance = 1.0d-30
 
-    ! wind -----------------------------------------------------------
-    if (wind_forcing) then
-        ! Force only the top layer of water, assumes top most layer is last
-        ! to go dry
-        do j=1,my
-            yc = ylower + (j - 0.5d0) * dy
-            do i=1,mx
-                xc = xlower + (i - 0.5d0) * dx
-                if (q(1,i,j) / rho(1) > dry_tolerance(1)) then
-                    psi = atan2(yc - sloc(2), xc - sloc(1))
-                    if (theta > psi) then
-                        phi = (2.d0 * pi - theta + psi) * RAD2DEG
-                    else
-                        phi = (psi - theta) * RAD2DEG 
-                    endif
-                    wind_speed = sqrt(aux(wind_index,i,j)**2        &
-                                    + aux(wind_index+1,i,j)**2)
-                    tau = wind_drag(wind_speed, phi) * rho_air * wind_speed
-                    q(2,i,j) = q(2,i,j) + dt * tau * aux(wind_index,i,j)
-                    q(3,i,j) = q(3,i,j) + dt * tau * aux(wind_index+1,i,j)
-                endif
-            enddo
-        enddo
-    endif
-    ! ----------------------------------------------------------------
-
-    ! Atmosphere Pressure --------------------------------------------
-    if (pressure_forcing) then
-        do j=1,my  
-            ym = ylower + (j - 1.d0) * dy
-            yc = ylower + (j - 0.5d0) * dy
-            yp = ylower + j * dy
-            do i=1,mx  
-                xm = xlower + (i - 1.d0) * dx
-                xc = xlower + (i - 0.5d0) * dx
-                xp = xlower + i * dx
-                
-                if (coordinate_system == 2) then
-                    ! Convert distance in lat-long to meters
-                    dx_meters = spherical_distance(xp,yc,xm,yc)
-                    dy_meters = spherical_distance(xc,yp,xc,ym)
-                else
-                    dx_meters = dx
-                    dy_meters = dy
-                endif
-
-                ! Calculate gradient of Pressure
-                P_gradient(1) = (aux(pressure_index,i+1,j) &
-                               - aux(pressure_index,i-1,j)) / (2.d0 * dx_meters)
-                P_gradient(2) = (aux(pressure_index,i,j+1) &
-                               - aux(pressure_index,i,j-1)) / (2.d0 * dy_meters)
-
-                ! Modify momentum in each layer
-                do k=1,num_layers
-                    layer_index = 3 * (k - 1)
-                    h(k) = q(layer_index + 1, i, j) / rho(k)
-                    if (h(k) > dry_tolerance(k)) then
-                        q(layer_index + 2, i, j) = q(layer_index + 2, i, j)   &
-                                    - dt * h(k) * P_gradient(1)
-                        q(layer_index + 3, i, j) = q(layer_index + 3, i, j)   &
-                                    - dt * h(k) * P_gradient(2)
-                    end if
-                end do
-            enddo
-        enddo
-    endif
+    character(len=*), parameter :: CFL_FORMAT =   &
+                        "('*** WARNING *** Courant number  =', d12.4," // &
+                         "'  is larger than input cfl_max = ', d12.4," // &
+                         "' in src2.')"
 
     ! ----------------------------------------------------------------
     ! Friction source term - Use backward Euler to solve
@@ -136,7 +69,7 @@ subroutine src2(meqn,mbc,mx,my,xlower,ylower,dx,dy,q,maux,aux,t,dt)
                 m = num_layers
                 found = .false.
                 do while(.not.found .and. m > 0)
-                    if (h(m) > friction_tolerance) then
+                    if (h(m) > depth_tolerance) then
                         ! Extract momentum components and exit loop
                         bottom_layer = m
                         bottom_index = 3 * (m - 1)
@@ -155,11 +88,22 @@ subroutine src2(meqn,mbc,mx,my,xlower,ylower,dx,dy,q,maux,aux,t,dt)
                     cycle
                 end if
 
+                if (variable_friction) then
+                    coeff = aux(friction_index, i, j)
+                else
+                    do nman = num_manning, 1, -1
+                        if (aux(1,i,j) < manning_break(nman)) then
+                            coeff = manning_coefficient(nman)
+                        endif
+                    enddo
+                end if
+
                 ! Apply friction if in shallow enough water
                 if (sum(h) <= friction_depth) then
-                    tau = g * aux(friction_index,i,j)**2 / h(bottom_layer)**(fric_coefficient) &
-                            * (1.d0 + (H_break / h(bottom_layer))**theta_f)**(gamma_f / theta_f) &
-                            * sqrt(hu**2 + hv**2)
+                    tau = g * coeff**2 / h(bottom_layer)**(manning_power) &
+                            * sqrt(hu**2 + hv**2) &
+                            * (1.d0 + (H_break / h(bottom_layer))**theta_f)**(gamma_f / theta_f)
+                            
                     q(bottom_index + 2,i,j) = q(bottom_index + 2,i,j) / (1.d0 + dt * tau)
                     q(bottom_index + 3,i,j) = q(bottom_index + 3,i,j) / (1.d0 + dt * tau)
                 endif
@@ -189,9 +133,9 @@ subroutine src2(meqn,mbc,mx,my,xlower,ylower,dx,dy,q,maux,aux,t,dt)
 
             do i=1,mx
                 do m=1,num_layers
-                    layer_index = 3 * (m-1)
-                    hu = q(layer_index + 2,i,j)
-                    hv = q(layer_index + 3,i,j)
+                    layer = 3 * (m-1)
+                    hu = q(layer + 2,i,j)
+                    hv = q(layer + 3,i,j)
                     ! Note that these are not really hu, hv but rho * hu and 
                     ! rho * hv actually
                     q(2,i,j) = hu * a(1,1) + hv * a(1,2)
@@ -202,4 +146,75 @@ subroutine src2(meqn,mbc,mx,my,xlower,ylower,dx,dy,q,maux,aux,t,dt)
     endif
     ! End of coriolis source term
 
+    ! wind -----------------------------------------------------------
+    if (wind_forcing) then
+        ! Force only the top layer of water, assumes top most layer is last
+        ! to go dry
+        ! Need storm location and direction for sector based wind drag
+        sloc = storm_location(t)
+        theta = storm_direction(t)
+        do j=1,my
+            yc = ylower + (j - 0.5d0) * dy
+            do i=1,mx
+                xc = xlower + (i - 0.5d0) * dx
+                if (q(1,i,j) / rho(1) > dry_tolerance(1)) then
+                    psi = atan2(yc - sloc(2), xc - sloc(1))
+                    if (theta > psi) then
+                        phi = (2.d0 * pi - theta + psi) * RAD2DEG
+                    else
+                        phi = (psi - theta) * RAD2DEG 
+                    endif
+                    wind_speed = sqrt(aux(wind_index,i,j)**2        &
+                                    + aux(wind_index+1,i,j)**2)
+                    tau = wind_drag(wind_speed, phi) * rho_air * wind_speed
+                    q(2,i,j) = q(2,i,j) + dt * tau * aux(wind_index,i,j)
+                    q(3,i,j) = q(3,i,j) + dt * tau * aux(wind_index+1,i,j)
+                endif
+            enddo
+        enddo
+    endif
+    ! ----------------------------------------------------------------
+
+    ! Atmosphere Pressure --------------------------------------------
+    ! Not yet handled in Riemann solver
+    ! if (pressure_forcing) then
+    !     do j=1,my  
+    !         ym = ylower + (j - 1.d0) * dy
+    !         yc = ylower + (j - 0.5d0) * dy
+    !         yp = ylower + j * dy
+    !         do i=1,mx  
+    !             xm = xlower + (i - 1.d0) * dx
+    !             xc = xlower + (i - 0.5d0) * dx
+    !             xp = xlower + i * dx
+                
+    !             if (coordinate_system == 2) then
+    !                 ! Convert distance in lat-long to meters
+    !                 dx_meters = spherical_distance(xp,yc,xm,yc)
+    !                 dy_meters = spherical_distance(xc,yp,xc,ym)
+    !             else
+    !                 dx_meters = dx
+    !                 dy_meters = dy
+    !             endif
+
+    !             ! Calculate gradient of Pressure
+    !             P_gradient(1) = (aux(pressure_index,i+1,j) &
+    !                            - aux(pressure_index,i-1,j)) / (2.d0 * dx_meters)
+    !             P_gradient(2) = (aux(pressure_index,i,j+1) &
+    !                            - aux(pressure_index,i,j-1)) / (2.d0 * dy_meters)
+
+    !             ! Modify momentum in each layer
+    !             do k=1,num_layers
+    !                 layer = 3 * (k - 1)
+    !                 h(k) = q(layer + 1, i, j) / rho(k)
+    !                 if (h(k) > dry_tolerance(k)) then
+    !                     q(layer + 2, i, j) = q(layer + 2, i, j)   &
+    !                                 - dt * h(k) * P_gradient(1)
+    !                     q(layer + 3, i, j) = q(layer + 3, i, j)   &
+    !                                 - dt * h(k) * P_gradient(2)
+    !                 end if
+    !             end do
+    !         enddo
+    !     enddo
+    ! endif
+
 end subroutine src2
\ No newline at end of file
