@@ -13,6 +13,8 @@ c
       use gauges_module, only: print_gauges_and_reset_nextLoc
 
       use storm_module, only: landfall, display_landfall_time
+      use fgmax_module, only: FG_num_fgrids, FG_fgrids, fgrid
+
 
 
       implicit double precision (a-h,o-z)
@@ -21,8 +23,10 @@ c
       dimension dtnew(maxlv), ntogo(maxlv), tlevel(maxlv)
       integer(kind=8) :: clock_start, clock_finish, clock_rate
       integer(kind=8) :: tick_clock_finish, tick_clock_rate
+      integer ifg
       character(len=128) :: time_format
       real(kind=8) cpu_start,cpu_finish
+      type(fgrid), pointer :: fg
 
 c
 c :::::::::::::::::::::::::::: TICK :::::::::::::::::::::::::::::
@@ -259,11 +263,46 @@ c integrate all grids at level 'level'.
 c
  90       continue
 
+          ! Only compute the mininum of fg%levelmax if necessary,
+          ! and only once per time step on each level, not on each patch:
+          do ifg=1,FG_num_fgrids
+              fg => FG_fgrids(ifg)
+              if (fg%min_level_check == mxnest) then
+                  fg%min_levelmax_checked = mxnest
+                else
+                  fg%min_levelmax_checked = minval(fg%levelmax)
+                endif
+                enddo
+c 
+c         ! time after step:
+          timenew = tlevel(level)+possk(level)
+
+          ! is it time to update fgmax grids on any level?
+          ! if so, set fg%update_now(level) to .true.
+          do ifg=1,FG_num_fgrids
+              fg => FG_fgrids(ifg)
+              if ((timenew >= fg%tstart_max) .and. 
+     &            (timenew <= fg%tend_max) .and.
+     &            (timenew >= fg%t_last_updated(level)  
+     &                         + fg%dt_check) .and.
+     &            (level >= fg%min_level_check) .and.
+     &            (level >= fg%min_levelmax_checked)) then 
+
+                      fg%update_now(level) = .true.
+                      fg%t_last_updated(level) = timenew
+                      !write(6,660) level, timenew
+ 660                  format('+++ update fgmax on level ',i1,
+     &                       ' at t = ',f12.2)
+              else
+                      fg%update_now(level) = .false.
+                      endif
+              enddo
+
 
           call advanc(level,nvar,dtlevnew,vtime,naux)
 
+
 c Output time info
-          timenew = tlevel(level)+possk(level)
           time_format = "(' AMRCLAW: level ',i2,'  CFL = ',e8.3," //
      &                  "'  dt = ',e10.4,  '  final t = ',e12.6)"
           if (display_landfall_time) then
@@ -334,12 +373,12 @@ c                   adjust time steps for this and finer levels
                      write(6,1006) intratx(level-1),intraty(level-1),
      &                             kratio(level-1),level
                      write(6,*) "Writing checkpoint file at t = ",time
-                     call check(ncycle,time,nvar,naux)
                      if (num_gauges .gt. 0) then
                         do ii = 1, num_gauges
                            call print_gauges_and_reset_nextLoc(ii)
                         end do
                      endif
+                     call check(ncycle,time,nvar,naux)
                      stop
                  endif
 
@@ -399,13 +438,13 @@ c             ! use same alg. as when setting refinement when first make new fin
 
  201  if ((abs(checkpt_style).eq.3 .and. 
      &      mod(ncycle,checkpt_interval).eq.0) .or. dumpchk) then
-                call check(ncycle,time,nvar,naux)
-                dumpchk = .true.
                if (num_gauges .gt. 0) then
                   do ii = 1, num_gauges
                      call print_gauges_and_reset_nextLoc(ii)
                   end do
                endif
+               call check(ncycle,time,nvar,naux)
+               dumpchk = .true.
        endif
 
        if ((mod(ncycle,iout).eq.0) .or. dumpout) then
@@ -450,6 +489,7 @@ c
                  call print_gauges_and_reset_nextLoc(ii)
               end do
            endif
+           dumpout = .true.
       endif
 
 c  # checkpoint everything for possible future restart
@@ -464,15 +504,20 @@ c
 c  # checkpoint everything for possible future restart
 c  # (unless we just did it based on dumpchk)
 c
+      ! write gauges first in case lagrangian gauge x,y needed by check         
+      if (num_gauges .gt. 0) then
+         if (.not. dumpout) then
+             ! normally this was done already, unless nout = 0
+             do ii = 1, num_gauges
+                call print_gauges_and_reset_nextLoc(ii)
+             end do
+         endif
+      endif
+      
       if (checkpt_style .ne. 0) then  ! want a chckpt
          ! check if just did it so dont do it twice
          if (.not. dumpchk) call check(ncycle,time,nvar,naux)
       endif
-      if (num_gauges .gt. 0) then
-         do ii = 1, num_gauges
-            call print_gauges_and_reset_nextLoc(ii)
-         end do
-      endif
 
       write(6,*) "Done integrating to time ",time
       return
