@@ -7,6 +7,7 @@ to test, or
 to create new regression data for archiving.
 """
 
+from __future__ import absolute_import
 import os
 import sys
 import unittest
@@ -14,11 +15,11 @@ import shutil
 
 import numpy
 
-import clawpack.geoclaw.tests as tests
+import clawpack.geoclaw.test as test
 import clawpack.geoclaw.topotools as topotools
 import clawpack.geoclaw.dtopotools as dtopotools
 
-class DTopoTests(tests.GeoClawTest):
+class DTopoTests(test.GeoClawRegressionTest):
     
     def setUp(self):
 
@@ -31,7 +32,8 @@ class DTopoTests(tests.GeoClawTest):
         topo.topo_type = 2
         topo.x = numpy.linspace(-10.0, 10.0, 201)
         topo.y = numpy.linspace(-10.0, 10.0, 201)
-        topo.write(os.path.join(self.temp_path, "topo1.topotype2"))
+        topo.write(os.path.join(self.temp_path, "topo1.topotype2"), \
+                topo_type=2, Z_format="%22.15e")
 
         h0 = 1000.0
         topo_func = lambda x,y: -h0*(1. + numpy.exp(x+y))
@@ -39,7 +41,8 @@ class DTopoTests(tests.GeoClawTest):
         topo.topo_type = 2
         topo.x = numpy.linspace(-0.5, -0.3, 21)
         topo.y = numpy.linspace(-0.1, 0.4, 51)
-        topo.write(os.path.join(self.temp_path, "topo2.topotype2"))
+        topo.write(os.path.join(self.temp_path, "topo2.topotype2"), \
+                topo_type=2, Z_format="%22.15e")
 
         # Make dtopography
         subfault_path = os.path.join(self.test_path, "dtopo1.csv")
