@@ -1,16 +1,26 @@
 #!/usr/bin/env python
 
+from __future__ import absolute_import
+from __future__ import print_function
 import os
 import sys
 import tempfile
 import shutil
 
+try:
+    # For Python 3.0 and later
+    from urllib.error import URLError
+except ImportError:
+    # Fall back to Python 2's urllib2
+    from urllib2 import URLError
+
 import numpy
 
 import nose
 
 import clawpack.geoclaw.topotools as topotools
-import clawpack.geoclaw.util as util
+import clawpack.clawutil.data
+from six.moves import range
 
 # Set local test directory to get local files
 testdir = os.path.dirname(__file__)
@@ -60,9 +70,9 @@ def test_read_write_topo_bowl():
 
     temp_path = tempfile.mkdtemp()
     try:
-        for topo_type in xrange(1, 4):
+        for topo_type in range(1, 4):
             path = os.path.join(temp_path, 'bowl.tt%s' % topo_type)
-            topo.write(path, topo_type=topo_type)
+            topo.write(path, topo_type=topo_type,Z_format="%22.15e")
 
             topo_in = topotools.Topography(path)
             assert numpy.allclose(topo.Z, topo_in.Z), \
@@ -111,8 +121,8 @@ def test_against_old():
     Test against the old topotools from 5.1.0.
     Compare bowl.tt1 to bowl_old.tt1
     """
-
-    import old_topotools
+    
+    from . import old_topotools
 
     nxpoints = 5
     nypoints = 4
@@ -169,9 +179,9 @@ def test_read_write_topo_bowl_hill():
         topo.x = numpy.linspace(-1.5, 2.5, 101)
         topo.y = numpy.linspace(-1.0, 2.0, 76)
 
-        for topo_type in xrange(1,4):
+        for topo_type in range(1,4):
             file_path = os.path.join(temp_path, 'bowl_hill.tt%s' % topo_type)
-            topo.write(file_path, topo_type=topo_type)
+            topo.write(file_path, topo_type=topo_type,Z_format="%22.15e")
             topo_in = topotools.Topography(path=file_path, topo_type=topo_type)
             assert numpy.allclose(topo.Z, topo_in.Z), \
                    "Written file of topo_type=%s does not equal read in" + \
@@ -186,6 +196,58 @@ def test_read_write_topo_bowl_hill():
         shutil.rmtree(temp_path)
 
 
+def test_netcdf():
+    r"""Test Python NetCDF formatted topography reading"""
+
+    temp_path = tempfile.mkdtemp()
+
+    try:
+        # Fetch comparison data
+        url = "".join(('https://raw.githubusercontent.com/rjleveque/geoclaw/',
+                       '5f675256c043e59e5065f9f3b5bdd41c2901702c/src/python/',
+                       'geoclaw/tests/kahului_sample_1s.tt2'))
+        clawpack.clawutil.data.get_remote_file(url, output_dir=temp_path,
+                                                    force=True)
+        
+        # Paths
+        local_path = os.path.join(temp_path, os.path.basename(url))
+        nc_path = os.path.join(temp_path, "test.nc")
+
+        # Write out NetCDF version of file
+        ascii_topo = topotools.Topography(path=local_path)
+        ascii_topo.read()
+        ascii_topo.write(nc_path, topo_type=4,Z_format="%22.15e")
+
+        # Read back in NetCDF file
+        nc_topo = topotools.Topography(path=nc_path)
+        nc_topo.read()
+
+        # Compare arrays - use tolerance based on 30 arcsecond accuracy
+        assert numpy.allclose(ascii_topo.x, nc_topo.x), \
+                    "Flat x-arrays did not match."
+        assert numpy.allclose(ascii_topo.y, nc_topo.y), \
+                    "Flat y-arrays did not match."
+        assert numpy.allclose(ascii_topo.Z, nc_topo.Z), \
+                    "Flat y-arrays did not match."
+
+    except AssertionError as e:
+        shutil.copytree(temp_path, os.path.join(os.getcwd()),
+            'test_read_netcdf')
+        raise e
+
+    except ImportError as e:
+        raise nose.SkipTest("Skipping test since NetCDF support not found.")
+
+    except RuntimeError as e:
+        raise nose.SkipTest("NetCDF topography test skipped due to " +
+                            "runtime failure.")
+    except URLError:
+        raise nose.SkipTest("Could not fetch remote file, skipping test.")
+    
+    finally:
+        shutil.rmtree(temp_path)
+
+
 def test_get_remote_file():
     """Test the ability to fetch a remote file from the web."""
     
@@ -195,7 +257,8 @@ def test_get_remote_file():
         url = "".join(('https://raw.githubusercontent.com/rjleveque/geoclaw/',
                        '5f675256c043e59e5065f9f3b5bdd41c2901702c/src/python/',
                        'geoclaw/tests/kahului_sample_1s.tt2'))
-        util.get_remote_file(url, output_dir=temp_path, force=True)
+        clawpack.clawutil.data.get_remote_file(url, output_dir=temp_path,
+            force=True)
 
         local_path = os.path.join(temp_path, os.path.basename(url))
         download_topo = topotools.Topography(path=local_path)
@@ -208,6 +271,10 @@ def test_get_remote_file():
     except AssertionError as e:
         shutil.copy(local_path, os.path.join(os.getcwd(), "remote_file.tt2"))
         raise e
+
+    except URLError:
+        raise nose.SkipTest("Could not fetch remote file, skipping test.")
+
     finally:
         shutil.rmtree(temp_path)
 
@@ -249,13 +316,13 @@ def test_unstructured_topo(save=False, plot=False):
         topo.plot(axes=axes, region_extent=[0, 1, 0, 1])
         axes.set_title("Unstructured Field")
 
-    topo.interp_unstructured(fill_topo, extent=[0, 1, 0, 1], delta=1e-2)
+    topo.interp_unstructured(fill_topo, extent=[0, 1, 0, 1], delta=(1e-2,1e-2))
     assert not topo.unstructured
 
     # Load (and save) test data and make the comparison
     test_data_path = os.path.join(testdir, "data", "unstructured_test_data.tt3")
     if save:
-        topo.write(test_data_path)
+        topo.write(test_data_path,Z_format="%22.15e")
 
     compare_data = topotools.Topography(path=test_data_path)
 
@@ -275,7 +342,12 @@ def plot_topo_bowl_hill():
     Create topo and write out, then read in again and plot.
     Note that center of bowl should be at (0,0).
     """
-    import matplotlib
+
+    try:
+        import matplotlib
+    except ImportError:
+        raise nose.SkipTest("Skipping test since matplotlib not found.")
+
     matplotlib.use("Agg")  # use image backend -- needed for Travis tests
     import matplotlib.pyplot as plt
 
@@ -288,14 +360,14 @@ def plot_topo_bowl_hill():
     topo.plot()
     fname = "bowl_hill.png"
     plt.savefig(fname)
-    print "Created ",fname
+    print("Created ",fname)
 
     topo2 = topo.crop([0.5, 1.5, 0., 2.])
     topo2.plot()
     plt.title("Cropped topography")
     fname = "bowl_hill_crop.png"
     plt.savefig(fname)
-    print "Created ",fname
+    print("Created ",fname)
 
 
 def plot_kahului():
@@ -307,7 +379,12 @@ def plot_kahului():
     In addition to using the Topography.plot function, also 
     illustrate how to do a contour data of the data directly.
     """
-    import matplotlib
+
+    try:
+        import matplotlib
+    except ImportError:
+        raise nose.SkipTest("Skipping test since matplotlib not found.")
+
     matplotlib.use("Agg")  # use image backend -- needed for Travis tests
     import matplotlib.pyplot as plt
 
@@ -319,7 +396,7 @@ def plot_kahului():
     plt.title("Kahului Harbor at 1 second resolution")
     fname = "kahului_imshow.png"
     plt.savefig(fname)
-    print "Created ",fname
+    print("Created ",fname)
 
     assert K.Z.shape == (46, 65), "*** K.Z is wrong shape"
     assert numpy.allclose(K.Z[:3,:3], \
@@ -348,14 +425,14 @@ def plot_kahului():
               fontsize=12)
     fname = "kahului_contour.png"
     plt.savefig(fname)
-    print "Created ",fname
+    print("Created ",fname)
 
 
 if __name__ == "__main__":
     if len(sys.argv) > 1:
         if "plot" in sys.argv[1].lower():
-            plot_topo_bowl_hill()
             plot_kahului()
+            plot_topo_bowl_hill()
             test_unstructured_topo(save=False, plot=True)
         elif bool(sys.argv[1]):
             test_unstructured_topo(save=True)
@@ -367,5 +444,6 @@ if __name__ == "__main__":
         test_read_write_topo_bowl_hill()
         test_get_remote_file()
         test_unstructured_topo()
+        test_netcdf()
 
-        print "All tests passed."
+        print("All tests passed.")
