@@ -8,7 +8,7 @@ Burgers' equation
 Solve the inviscid Burgers' equation:
 
 .. math:: 
-    q_t + \frac{1}{2} (q^2)_x & = 0.
+    q_t + \frac{1}{2} (q^2)_x = 0.
 
 This is a nonlinear PDE often used as a very simple
 model for fluid dynamics.
@@ -16,6 +16,7 @@ model for fluid dynamics.
 The initial condition is sinusoidal, but after a short time a shock forms
 (due to the nonlinearity).
 """
+from __future__ import absolute_import
 import numpy as np
 from clawpack import riemann
 
@@ -42,7 +43,7 @@ def setup(use_petsc=0,kernel_language='Fortran',outdir='./_output',solver_type='
     solver.bc_lower[0] = pyclaw.BC.periodic
     solver.bc_upper[0] = pyclaw.BC.periodic
 
-    x = pyclaw.Dimension('x',0.0,1.0,500)
+    x = pyclaw.Dimension(0.0,1.0,500,name='x')
     domain = pyclaw.Domain(x)
     num_eqn = 1
     state = pyclaw.State(domain,num_eqn)
