@@ -30,11 +30,12 @@ subroutine rpt2(ixy,imp,maxm,meqn,mwaves,maux,mbc,mx,ql,qr,aux1,aux2,aux3,asdq,b
 
     use amr_module, only: mcapa
     
-    use geoclaw_module, only: g => grav, earth_radius, pi
+    use geoclaw_module, only: g => grav, rho, earth_radius, pi
+    use geoclaw_module, only: coordinate_system
 
     use multilayer_module, only: num_layers, eigen_method, inundation_method
     use multilayer_module, only: eigen_func, inundation_eigen_func
-    use multilayer_module, only: dry_tolerance, rho, aux_layer_index
+    use multilayer_module, only: dry_tolerance, aux_layer_index
 
     implicit none
 
@@ -199,7 +200,7 @@ subroutine rpt2(ixy,imp,maxm,meqn,mwaves,maux,mbc,mx,ql,qr,aux1,aux2,aux3,asdq,b
         endif
 
         ! Handle lat-long coordinate systems
-        if (mcapa > 0) then
+        if (coordinate_system == 2) then
             if (ixy == 2) then
                 dxdcp=(earth_radius*pi/180.d0)
                 dxdcm = dxdcp
@@ -250,7 +251,7 @@ subroutine rpt2_single_layer(ixy,imp,ql,qr,aux1,aux2,aux3,asdq,bmasdq,bpasdq)
 
     use amr_module, only: mcapa
 
-    use geoclaw_module, only: g => grav, earth_radius, pi
+    use geoclaw_module, only: g => grav, earth_radius, pi, coordinate_system
     use multilayer_module, only: num_layers, eigen_method, inundation_method
     use multilayer_module, only: dry_tolerance
 
@@ -338,27 +339,28 @@ subroutine rpt2_single_layer(ixy,imp,ql,qr,aux1,aux2,aux3,asdq,bmasdq,bpasdq)
             topo1 = aux1(1,1)
             topo3 = aux3(1,1)
        else
-            eta = ql(1) + aux2(2,1)
-            topo1 = aux1(2,1)
-            topo3 = aux3(2,1)
+            eta = ql(1) + aux2(1,2)
+            topo1 = aux1(1,2)
+            topo3 = aux3(1,2)
        endif
        if (eta.lt.max(topo1,topo3)) go to 90
 
-      if (mcapa > 0) then
+      if (coordinate_system == 2) then
          if (ixy.eq.2) then
             dxdcp=(earth_radius*pi/180.d0)
             dxdcm = dxdcp
          else
             if (imp.eq.1) then
-               dxdcp = earth_radius*pi*cos(aux3(1,3))/180.d0
-               dxdcm = earth_radius*pi*cos(aux1(1,3))/180.d0
+               dxdcp = earth_radius*pi*cos(aux3(3,1))/180.d0
+               dxdcm = earth_radius*pi*cos(aux1(3,1))/180.d0
             else
-               dxdcp = earth_radius*pi*cos(aux3(2,3))/180.d0
-               dxdcm = earth_radius*pi*cos(aux1(2,3))/180.d0
+               dxdcp = earth_radius*pi*cos(aux3(3,2))/180.d0
+               dxdcm = earth_radius*pi*cos(aux1(3,2))/180.d0
             endif
          endif
       endif
 
+
 !=====Determine some speeds necessary for the Jacobian=================
             vhat=(vr*dsqrt(hr))/(dsqrt(hr)+dsqrt(hl)) + &
              (vl*dsqrt(hl))/(dsqrt(hr)+dsqrt(hl))
