@@ -206,10 +206,36 @@ def plot_frame(framesolns,plotdata,frameno=0,verbose=False):
                 # loop over patches:
                 # ----------------
 
+                num_skipped = 0
+                skip_patches_outside_xylimits = \
+                        getattr(plotaxes,'skip_patches_outside_xylimits',True)
+
                 for stateno,state in enumerate(framesoln.states):
 
                     patch = state.patch
 
+                    if skip_patches_outside_xylimits:
+                        # skip patches not visible based on xlimits,ylimits:
+                        if (plotaxes.xlimits is not None) \
+                                & (type(plotaxes.xlimits) is not str):
+                            if (patch.dimensions[0].lower \
+                                        >= plotaxes.xlimits[1]) \
+                                    or  (patch.dimensions[0].upper \
+                                        <= plotaxes.xlimits[0]):
+                                num_skipped += 1
+                                continue  # go to next patch
+    
+                        if len(patch.dimensions) > 1:
+                            # 2d patch
+                            if (plotaxes.ylimits is not None) \
+                                    & (type(plotaxes.ylimits) is not str):
+                                if (patch.dimensions[1].lower \
+                                            >= plotaxes.ylimits[1]) \
+                                        or  (patch.dimensions[1].upper \
+                                            <= plotaxes.ylimits[0]):
+                                    num_skipped += 1
+                                    continue  # go to next patch
+
                     current_data.add_attribute('patch',patch)
                     current_data.add_attribute("level",1)
                     current_data.add_attribute('q',state.q)
@@ -305,6 +331,11 @@ def plot_frame(framesolns,plotdata,frameno=0,verbose=False):
 
                     # end of loop over plotitems
                 # end of loop over patches
+
+            if False and num_skipped > 0:
+                # possible warning message:
+                print('Skipped plotting %i patches not visible' % num_skipped)
+
             # end of loop over framesolns
 
 
@@ -1046,10 +1077,14 @@ def printfig(fname='',frameno='', figno='', format='png', plotdir='.', \
         a.set_yticks([])
 
         plt.axis('off')
+
         if kml_figsize is not None:
             fig.set_size_inches(kml_figsize[0],kml_figsize[1])
-        plt.savefig(fname, transparent=True, bbox_inches='tight', \
-                      pad_inches=0,dpi=kml_dpi)
+        a.set_frame_on(False)
+        plt.subplots_adjust(top = 1, bottom = 0, right = 1, left = 0, 
+                        hspace = 0, wspace = 0)
+        plt.margins(0,0)
+        plt.savefig(fname, transparent=True, bbox_inches='tight',dpi=kml_dpi)
     else:
         plt.savefig(fname, bbox_inches=bbox_inches)
 
