@@ -88,7 +88,7 @@ class GaugeSolution(object):
     def __init__(self, number, location=None):
         
         warnings.warn("This version of GaugeSolution is deprecated, use the ",
-                      "class definition in clawpack.amrclaw.gauges instead.")
+                      "class definition in clawpack.pyclaw.gauges instead.")
 
         # Gauge descriptors
         self.number = number
@@ -410,9 +410,13 @@ def plotgauge1(gaugesoln, plotitem, current_data):
         var = gaugesoln.q[plot_var,:]
     else:
         try:
-            var = plot_var(gaugesoln)
+            var = plot_var(current_data)
         except:
-            raise Exception("Problem applying plot_var to gaugesoln")
+            print('Applying plot_var to current_data failed, try gaugesoln')
+            try:
+                var = plot_var(gaugesoln)
+            except:
+                raise Exception("Problem applying plot_var to gaugesoln")
     tmax = t.max()
     varmax = var.max()
 
